package local.targets;

/*!
 *  ======== ITIArm ========
 *  Common definitions for Arm targets
 *
 *  This interface is used by the `{@link TIArm11}` and `{@link TIArm11D}`
 *  modules in this package.  Its sole purpose is to encapsulate
 *  commonality between multiple targets defined in this
 *  package; in this case, `TIArm11` and `TIArm11D`.  We could
 *  have used this interface with `TIArm9` but choose not to
 *  for pedagogic reasons.
 */
metaonly interface ITIArm inherits ti.targets.ITarget
{
    override readonly config String rts = "local.targets.rts470";

    override config String stdInclude = "local/targets/std.h";
    
    override config String platform = "ti.platforms.sim470xx";

    override readonly config ti.targets.ITarget.Command ar = {
        cmd:  "ar470",
        opts: "rq"
    };

    override readonly config ti.targets.ITarget.Command vers = {
        cmd:  "cl470",
        opts: "-version"
    };

    override readonly config ti.targets.ITarget.Command lnk = {
        cmd:  "lnk470",
        opts: ""
    };

    /*!
     *  ======== asmOpts ========
     *  User configurable assembler options.
     *
     *  Defaults:
     *  @p(dlist)
     *	    -`-qq`
     *		super quiet mode
     */
    override config ti.targets.ITarget.Options asmOpts = {
	prefix: "-qq",
	suffix: ""
    };

    /*!
     *  ======== ccOpts ========
     *  User configurable compiler options.
     *
     *	Defaults:
     *  @p(dlist)
     *	    -`-q`
     *		quiet mode
     *	    -`-pdsw225`
     *		generate a warning for implicitly declared functions; i.e.,
     *		functions without prototypes
     */
    override config ti.targets.ITarget.Options ccOpts = {
        prefix: "-q -pdsw225",
        suffix: ""
    };

    /*!
     *  ======== lnkOpts ========
     *  User configurable linker options.
     *
     *  Defaults:
     *  @p(dlist)
     *	    -`-w`
     *		Display linker warnings
     *	    -`-q`
     *		Quite run
     *	    -`-u`
     *		Place unresolved external symbol into symbol table
     *	    -`-c`
     *		ROM autoinitialization model
     *	    -`-m`
     *		create a map file
     */
    override config ti.targets.ITarget.Options lnkOpts = {
        prefix: "-w -q -u _c_int00",
        suffix: "-c -m $(XDCCFGDIR)/$@.map " /* + -l $(rootDir)/lib/linkLib */
    };

    override config String includeOpts = "-I$(rootDir)/include";

    final override readonly config String sectMap[string] = [
	[".intvecs", "code"],

	[".text", "code"],
	[".cinit", "code"],
	[".const", "code"],
	[".pinit", "code"],

	[".bss", "data"],
	[".sysmem", "data"],
	[".stack", "stack"],
	[".args", "data"],
    ];
}
